@@ -629,10 +629,12 @@ int64_t decoder_ffmpeg::read_audio_data(int audio_stream, void *buffer, size_t s
             tmppacket = packet;
             while (tmppacket.size > 0)
             {
+                // Manage tmpbuf with av_malloc/av_free, to guarantee correct alignment.
+                // Not doing this results in hard to debug crashes on some systems.
                 int tmpbuf_size = (AVCODEC_MAX_AUDIO_FRAME_SIZE * 3) / 2;
-                unsigned char *tmpbuf = new unsigned char[tmpbuf_size];
+                unsigned char *tmpbuf = static_cast<unsigned char *>(av_malloc(tmpbuf_size));
                 int len = avcodec_decode_audio3(_stuff->audio_codec_ctxs[audio_stream],
-                        reinterpret_cast<int16_t *>(tmpbuf), &tmpbuf_size, &tmppacket);
+                        reinterpret_cast<int16_t *>(&(tmpbuf[0])), &tmpbuf_size, &tmppacket);
                 if (len < 0)
                 {
                     tmppacket.size = 0;
@@ -648,7 +650,7 @@ int64_t decoder_ffmpeg::read_audio_data(int audio_stream, void *buffer, size_t s
                 size_t old_size = _stuff->audio_buffers[audio_stream].size();
                 _stuff->audio_buffers[audio_stream].resize(old_size + tmpbuf_size);
                 memcpy(&(_stuff->audio_buffers[audio_stream][old_size]), tmpbuf, tmpbuf_size);
-                delete[] tmpbuf;
+                av_free(tmpbuf);
             }
             
             av_free_packet(&packet);
@@ -693,6 +695,8 @@ void decoder_ffmpeg::seek(int64_t dest_pos)
         {
             _stuff->audio_flush_flags[i] = true;
         }
+        /* The next read request must update the position */
+        _stuff->pos = std::numeric_limits<int64_t>::min();
     }
 }
 
@@ -759,3 +763,18 @@ void decoder_ffmpeg::close()
     delete _stuff;
     _stuff = NULL;
 }
+
+std::vector<std::string> ffmpeg_versions()
+{
+    std::vector<std::string> v;
+    v.push_back(str::asprintf("ffmpeg libavformat %d.%d.%d / %d.%d.%d",
+                LIBAVFORMAT_VERSION_MAJOR, LIBAVFORMAT_VERSION_MINOR, LIBAVFORMAT_VERSION_MICRO,
+                avformat_version() >> 16, avformat_version() >> 8 & 0xff, avformat_version() & 0xff));
+    v.push_back(str::asprintf("ffmpeg libavcodec %d.%d.%d / %d.%d.%d",
+                LIBAVCODEC_VERSION_MAJOR, LIBAVCODEC_VERSION_MINOR, LIBAVCODEC_VERSION_MICRO,
+                avcodec_version() >> 16, avcodec_version() >> 8 & 0xff, avcodec_version() & 0xff));
+    v.push_back(str::asprintf("ffmpeg libswscale %d.%d.%d / %d.%d.%d",
+                LIBSWSCALE_VERSION_MAJOR, LIBSWSCALE_VERSION_MINOR, LIBSWSCALE_VERSION_MICRO,
+                swscale_version() >> 16, swscale_version() >> 8 & 0xff, swscale_version() & 0xff));
+    return v;
+}
