@@ -119,6 +119,11 @@ enum input::mode input::mode_from_name(const std::string &name, bool *ok)
     return m;
 }
 
+bool input::mode_is_2d(enum input::mode m)
+{
+    return (m == mono);
+}
+
 void input::open(std::vector<decoder *> decoders,
         int video0_decoder, int video0_stream,
         int video1_decoder, int video1_stream,
@@ -204,6 +209,13 @@ void input::open(std::vector<decoder *> decoders,
         {
         }
     }
+    if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicLayout")))
+    {
+        if (std::string(tag_value) == "SideBySideRF" || std::string(tag_value) == "OverUnderRT")
+        {
+            _swap_eyes = true;
+        }
+    }
     if (_mode == automatic)
     {
         if (video1_decoder != -1)
@@ -214,17 +226,7 @@ void input::open(std::vector<decoder *> decoders,
         {
             if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicLayout")))
             {
-                if (std::string(tag_value) == "SideBySideRF")
-                {
-                    _mode = left_right;
-                    _swap_eyes = true;
-                    if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicHalfWidth"))
-                            && std::string(tag_value) == "1")
-                    {
-                        _mode = left_right_half;
-                    }
-                }
-                else if (std::string(tag_value) == "SideBySideLF")
+                if (std::string(tag_value) == "SideBySideRF" || std::string(tag_value) == "SideBySideLF")
                 {
                     _mode = left_right;
                     if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicHalfWidth"))
@@ -233,17 +235,7 @@ void input::open(std::vector<decoder *> decoders,
                         _mode = left_right_half;
                     }
                 }
-                else if (std::string(tag_value) == "OverUnderRT")
-                {
-                    _mode = top_bottom;
-                    _swap_eyes = true;
-                    if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicHalfHeight"))
-                            && std::string(tag_value) == "1")
-                    {
-                        _mode = top_bottom_half;
-                    }
-                }
-                else if (std::string(tag_value) == "OverUnderLT")
+                else if (std::string(tag_value) == "OverUnderRT" || std::string(tag_value) == "OverUnderLT")
                 {
                     _mode = top_bottom;
                     if ((tag_value = _decoders.at(_video_decoders[0])->tag_value("StereoscopicHalfHeight"))
