@@ -29,6 +29,9 @@
 class input
 {
 public:
+
+    /* The video input format */
+
     enum mode
     {
         mono,                   /* 1 video source: center view */
@@ -48,7 +51,7 @@ private:
     std::vector<decoder *> _decoders;
     int _video_decoders[2], _video_streams[2];
     int _audio_decoder, _audio_stream;
-    mode _mode;
+    enum mode _mode;
     bool _swap_eyes;
     int64_t _initial_skip;
     int _video_width;
@@ -64,16 +67,22 @@ private:
     blob _audio_buffer;
 
 public:
+
+    /* Constructor, Destructor */
+
     input() throw ();
     ~input();
 
+    /* Open input video and audio streams using the given decoder and stream indices */
     void open(std::vector<decoder *> decoders,
             int video0_decoder, int video0_stream,
             int video1_decoder, int video1_stream,
             int audio_decoder, int audio_stream,
             mode mode);
 
-    mode mode() const throw ()
+    /* Access input properties */
+
+    enum mode mode() const throw ()
     {
         return _mode;
     }
@@ -138,16 +147,27 @@ public:
         return _duration;
     }
 
+    /* Read audio and video data */
+
+    /* Read the next video frame into an internal buffer. Return its time stamp in microseconds,
+     * or a negative value on end-of-file. */
     int64_t read_video_frame();
+    /* Get the video frame that is currently in the internal buffer, in the given format. */
     void get_video_frame(enum decoder::video_frame_format fmt,
             uint8_t *l_data[3], size_t l_line_size[3],
             uint8_t *r_data[3], size_t r_line_size[3]);
+    /* Release the video frame from the internal buffer */
     void release_video_frame();
 
+    /* Read the requested amount of audio data from the input. The data will be stored in an
+     * internal buffer, and a pointer to that buffer is returned in 'data'. On end-of-file, a
+     * negative value is returned. */
     int64_t read_audio_data(void **data, size_t size);
 
+    /* Seek to the given position in microseconds. */
     void seek(int64_t dest_pos);
 
+    /* Close the input */
     void close();
 };
 
