@@ -1,6 +1,9 @@
 #ifndef PLAYER_EQUALIZER_H
 #define PLAYER_EQUALIZER_H
 
+#include <vector>
+#include <string>
+
 #include "player.h"
 
 
@@ -19,4 +22,6 @@ public:
     virtual void close();
 };
 
+std::vector<std::string> equalizer_versions();
+
 #endif
