@@ -38,6 +38,7 @@
 #include "player_qt.h"
 #include "qt_app.h"
 #include "video_output_opengl_qt.h"
+#include "lib_versions.h"
 
 
 player_qt_internal::player_qt_internal(video_output_opengl_qt *vo)
@@ -744,6 +745,7 @@ void main_window::open(QStringList filenames, bool automatic)
     if (automatic)
     {
         _init_data.input_mode = input::automatic;
+        _init_data.video_mode = video_output::automatic;
     }
     if (open_player())
     {
@@ -761,17 +763,24 @@ void main_window::open(QStringList filenames, bool automatic)
         }
         _settings->endGroup();
         _settings->beginGroup("Session");
-        if (_init_data.input_mode == input::mono)
+        if (automatic)
         {
-            QString fallback_mode_name = QString(video_output::mode_name(video_output::mono_left).c_str());
-            QString mode_name = _settings->value(QString("2d-output-mode"), fallback_mode_name).toString();
-            _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
+            if (_init_data.input_mode == input::mono)
+            {
+                QString fallback_mode_name = QString(video_output::mode_name(video_output::mono_left).c_str());
+                QString mode_name = _settings->value(QString("2d-output-mode"), fallback_mode_name).toString();
+                _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
+            }
+            else
+            {
+                QString fallback_mode_name = QString(video_output::mode_name(video_output::anaglyph_red_cyan_dubois).c_str());
+                QString mode_name = _settings->value(QString("3d-output-mode"), fallback_mode_name).toString();
+                _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
+            }
         }
         else
         {
-            QString fallback_mode_name = QString(video_output::mode_name(video_output::anaglyph_red_cyan_dubois).c_str());
-            QString mode_name = _settings->value(QString("3d-output-mode"), fallback_mode_name).toString();
-            _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
+            _init_data.video_mode = _player->video_mode();
         }
         _settings->endGroup();
         _in_out_widget->update(_init_data, true, false);
@@ -866,15 +875,24 @@ void main_window::help_keyboard()
 
 void main_window::help_about()
 {
-    QMessageBox::about(this, tr("About " PACKAGE_NAME), tr(
-                "<p>%1 version %2</p>"
-                "<p>Copyright (C) 2010 Martin Lambers and others.<br>"
-                "This is free software. You may redistribute copies of it under the terms of "
-                "the <a href=\"http://www.gnu.org/licenses/gpl.html\">"
-                "GNU General Public License</a>.<br>"
-                "There is NO WARRANTY, to the extent permitted by law.</p>"
-                "See <a href=\"%3\">%3</a> for more information on this software.</p>")
-            .arg(PACKAGE_NAME).arg(VERSION).arg(PACKAGE_URL));
+    QString blurb = tr(
+            "<p>%1 version %2</p>"
+            "<p>Copyright (C) 2010 Martin Lambers and others.<br>"
+            "This is free software. You may redistribute copies of it<br>"
+            "under the terms of the <a href=\"http://www.gnu.org/licenses/gpl.html\">"
+            "GNU General Public License</a>.<br>"
+            "There is NO WARRANTY, to the extent permitted by law.</p>"
+            "See <a href=\"%3\">%3</a> for more information on this software.</p>")
+        .arg(PACKAGE_NAME).arg(VERSION).arg(PACKAGE_URL);
+    blurb += tr("<p>Platform:<ul><li>%1</li></ul></p>").arg(PLATFORM);
+    blurb += QString("<p>Libraries used:<ul>");
+    std::vector<std::string> libs = lib_versions();
+    for (size_t i = 0; i < libs.size(); i++)
+    {
+        blurb += tr("<li>%1</li>").arg(libs[i].c_str());
+    }
+    blurb += QString("</ul></p>");
+    QMessageBox::about(this, tr("About " PACKAGE_NAME), blurb);
 }
 
 
