@@ -20,6 +20,9 @@
 #ifndef VIDEO_OUTPUT_OPENGL_QT_H
 #define VIDEO_OUTPUT_OPENGL_QT_H
 
+#include <vector>
+#include <string>
+
 #include <GL/glew.h>
 
 #include <QGLWidget>
@@ -92,4 +95,6 @@ public:
 friend class video_output_opengl_qt_widget;
 };
 
+std::vector<std::string> opengl_versions();
+
 #endif
